<div class="card overflow-hidden">
    <div class="card-header pl-2 border-bottom-0">
        <div class="font-weight-bold">
            @if(@$from)
                Appointments for {{friendly_date($from)}}
            @else
                Appointments
            @endif
        </div>
    </div>
    <div class="card-body p-0 max-height-200px overflow-auto">
        @if(@$appointments && count($appointments))
            <table class="mb-0 table table-sm table-striped appointments border-top-0">
                @foreach($appointments as $appointment)
                    <tr class="{{$appointment->bgColor}}">
                        <td>
                            <div class="d-flex align-items-baseline">
                                <a href="/patients/view/{{$appointment->clientUid}}" class="font-weight-bold d-block">
                                    {{$appointment->clientName }}
                                </a>
                                @if(request()->input('for') === 'na')
                                    <span class="mx-2 text-secondary">•</span>
                                    <span class="text-secondary font-weight-normal">{{$appointment->proName}}</span>
                                @endif
                            </div>
                            <div class="mt-1">
                                <a href="/patients/view/{{$appointment->clientUid}}/calendar/{{$appointment->uid}}">
                                    {{ $appointment->friendlyStartTime }} - {{ $appointment->friendlyEndTime }}</a>
                                <span class="text-secondary">{{ friendly_timezone($appointment->timezone) }}</span>
                            </div>
                            @if($appointment->title)
                                <span class="d-inline-block mt-1 text-secondary text-sm">
                            {{ $appointment->title }}
                        </span>
                            @endif
                        </td>
                        <td>
                            <div class="d-flex flex-column">
                                <div class="d-flex align-items-baseline flex-nowrap">
                                    @if($appointment->status === 'PENDING')
                                        <div class="text-warning-mellow font-weight-bold text-nowrap">
                                            <i class="fa fa-exclamation-triangle"></i>
                                            Pending
                                        </div>
                                    @elseif($appointment->status === 'CONFIRMED')
                                        <div class="text-success font-weight-bold text-nowrap">
                                            <i class="fa fa-check"></i>
                                            Confirmed
                                        </div>
                                    @elseif($appointment->status === 'CANCELLED')
                                        <div class="text-danger font-weight-bold text-nowrap">
                                            <i class="fa fa-stop"></i>
                                            Cancelled
                                        </div>
                                    @elseif($appointment->status === 'COMPLETED')
                                        <div class="text-success font-weight-bold text-nowrap">
                                            <i class="far fa-calendar-check"></i>
                                            Completed
                                        </div>
                                    @endif
                                    <div class="ml-2" moe relative center>
                                        <a href="#" start show><i class="fa fa-edit"></i></a>
                                        <form url="/api/appointment/updateStatus" hook="refreshDashboardAppointments" center>
                                            <input type="hidden" name="uid" value="{{$appointment->uid}}">
                                            <p class="text-nowrap mb-3 font-weight-bold text-secondary">Change appointment status</p>
                                            <div class="mb-3 border bg-light p-2">
                                                <div class="d-flex align-items-baseline mb-1">
                                                    <span class="width-70px">Patient</span>
                                                    <b>{{$appointment->clientName }}</b>
                                                </div>
                                                <div class="d-flex align-items-baseline mb-1">
                                                    <span class="width-70px">Pro</span>
                                                    <b>{{$appointment->proName}}</b>
                                                </div>
                                                <div class="d-flex align-items-baseline mb-1">
                                                    <span class="width-70px">Date</span>
                                                    <b>{{friendly_date($appointment->raw_date)}}</b>
                                                </div>
                                                <div class="d-flex align-items-baseline mb-1">
                                                    <span class="width-70px">Time</span>
                                                    <span>
                                                        <b>{{ $appointment->friendlyStartTime }}</b> - <b>{{ $appointment->friendlyEndTime }}</b>
                                                        <span class="text-secondary">{{ friendly_timezone($appointment->timezone) }}</span>
                                                    </span>
                                                </div>
                                                <div class="d-flex align-items-baseline ">
                                                    <span class="width-70px">Status</span>
                                                    <b>{{ucwords(strtolower($appointment->status))}}</b>
                                                </div>
                                            </div>
                                            <label for="" class="mb-2">New Status</label>
                                            <select name="status" class="form-control form-control-sm input-sm bg-light mb-2">
                                                <option value="PENDING" {{$appointment->status === 'PENDING' ? 'selected' : ''}}>PENDING</option>
                                                <option value="CONFIRMED" {{$appointment->status === 'CONFIRMED' ? 'selected' : ''}}>CONFIRMED</option>
                                                <option value="CANCELLED" {{$appointment->status === 'CANCELLED' ? 'selected' : ''}}>CANCELLED</option>
                                                <option value="COMPLETED" {{$appointment->status === 'COMPLETED' ? 'selected' : ''}}>COMPLETED</option>
                                            </select>
                                            <div class="mb-0">
                                                <button class="btn btn-primary btn-sm" submit>Submit</button>
                                                <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                                            </div>
                                        </form>
                                    </div>
                                </div>
                                @if($from === date('Y-m-d'))
                                    <div class="{{$appointment->started ? 'text-danger': 'text-secondary'}}">
                                        {{ $appointment->inHowManyHours }}
                                    </div>
                                @endif
                            </div>
                        </td>
                        <td>
                            <div>
                                @if($appointment->coverage === 'YES')
                                    <b class="text-success">Covered</b>
                                @elseif($appointment->coverage === 'NO')
                                    <b class="text-danger">Not Covered</b>
                                @else
                                    <b v-else class="text-warning-mellow">Pending</b>
                                @endif
                            </div>
                        </td>
                    </tr>
                @endforeach
            </table>
        @else
            @if(@$from)
                <div class="bg-light p-3 text-secondary">
                    <span>You have no appointments on <b>{{ $from }}</b></span>
                </div>
            @else
                <div class="bg-light p-3 text-secondary">
                    Please select a date from the calendar on the left
                </div>
            @endif
        @endif
    </div>
</div>

