<?php

use App\Models\Point;
use App\Models\Client;
use App\Models\Note;
use App\Models\Segment;

/** @var Client $patient */
/** @var Note $note */
/** @var Segment $segment */

$medications = Point::getIntakePointsOfCategory($patient, 'MEDICATION', $note);

?>
<div>

    <div class="d-flex mb-2">
        <table class="table table-sm table-bordered table-striped mb-0 bg-white">
            <thead>
            <tr class="">
                <th class="border-bottom-0 width-100px text-info">Relevant to<br>this visit</th>
                <th class="border-bottom-0">Medication</th>
                <th class="border-bottom-0">Most Recent Subjective</th>
                <th class="border-bottom-0">Most Recent Plan</th>
            </tr>
            </thead>
            <?php foreach($medications as $medication): ?>
                <tr>
                    <td class="p-0">
                        <?php $rel = $medication->relevanceToNote($note); ?>
                        <label class="d-flex align-items-center px-2 py-1 m-0 c-pointer">
                            <input type="checkbox" class="m-0 chk-relevance"
                                   data-point-uid="{{$medication->uid}}"
                                   data-rel-uid="{{$rel ? $rel->uid : ''}}"
                                    {{$rel ? 'checked' : ''}}>
                            <span>&nbsp;</span>
                        </label>
                    </td>
                    <td>
                        <div class="d-flex align-items-baseline">
                            <div class="<?= $medication->is_removed ? 'strike-through' : '' ?>">
                                <b><?= !!@($medication->data->name) ? @($medication->data->name) : '-' ?></b>
                            </div>

                            <!-- common actions -->
                            <div class="ml-auto d-inline-flex align-items-baseline pr-2">
                                <?php
                                $point = $medication;
                                $label = 'Medication';
                                include resource_path('views/app/patient/segment-templates/_common_actions/remove-undo.php');
                                ?>
                                @if($point->added_in_note_id === $note->id && $point->addition_reason_category == 'ON_INTAKE')
                                <div visit-moe class="ml-2">
                                    <a href="#" start show class="">Swap</a>
                                    <form url="/api/visitPoint/swapTopLevelEntryError" class="mcp-theme-1">
                                        <input type="hidden" name="uid" value="<?= $point->uid ?>">
                                        <input type="hidden" name="segmentUid" value="<?= $segment->uid ?>">
                                        <input type="hidden" name="category" value="MEDICATION">
                                        <input type="hidden" name="data">

                                        <input type="hidden" data-name="medId">
                                        <input type="hidden" data-name="routedMedId">
                                        <input type="hidden" data-name="routedDosageFormMedId">
                                        <input type="hidden" data-name="gcnSeqno">

                                        <p class="mb-2"><b>Add Medication (on intake)</b></p>

                                        <div class="mb-2">
                                            <label class="text-sm text-secondary mb-1">Medication</label>
                                            <input type="text"
                                                   data-name="name"
                                                   class="form-control form-control-sm"
                                                   stag-suggest
                                                   stag-suggest-ep="/fdb-med-suggest-v2/json">
                                        </div>
                                        <div class="mb-2">
                                            <label class="text-sm text-secondary mb-1">Start Date</label>
                                            <input type="date" class="form-control form-control-sm" data-name="start_date">
                                        </div>
                                        <div class="mb-2">
                                            <label class="text-sm text-secondary mb-1">Prescribed By</label>
                                            <input type="text" class="form-control form-control-sm" data-name="prescriber">
                                        </div>
                                        <div class="mb-2">
                                            <label class="text-sm text-secondary mb-1">Description</label>
                                            <textarea type="text" data-name="description" class="form-control form-control-sm"></textarea>
                                        </div>

                                        <div>
                                            <button submit class="btn btn-sm btn-primary mr-2">Submit</button>
                                            <button cancel class="btn btn-sm btn-default border">Cancel</button>
                                        </div>
                                    </form>
                                </div>
                                @endif
                            </div>
                        </div>
                        <?php if(!!@($medication->data->prescriber)): ?>
                        <div>
                            Prescribed by <?= $medication->data->prescriber ?>
                        </div>
                        <?php endif; ?>
                        <?php if(!!@($medication->data->start_date)): ?>
                        <div>
                            Started on <?= $medication->data->start_date ?>
                        </div>
                        <?php endif; ?>
                        <?php if(!!@($medication->removal_effective_date) && !$medication->is_removed_due_to_entry_error): ?>
                        <div>
                            Ended on <?= $medication->removal_effective_date ?>
                        </div>
                        <?php endif; ?>
                    </td>
                    <td>
                        <div class="d-flex align-items-start">
                            <div class="flex-grow-1">
                                <?php
                                $point = $medication;
                                include resource_path('views/app/patient/segment-templates/_child_review/last-review.php');
                                ?>
                            </div>
                            <div class="d-inline-flex flex-nowrap">
                                <a class="px-1 view-review-log"
                                   native target="_blank"
                                   open-in-stag-popup
                                   popup-style="stag-popup-md"
                                   title="Subjective log<?= !!@($medication->data->name) ? ' for ' . @($medication->data->name) : '' ?>"
                                   href="/point/review-log/<?= $medication->uid ?>?popupmode=1">
                                    <i class="fa fa-history"></i>
                                </a>
                                <?php
                                include resource_path('views/app/patient/segment-templates/_child_review/edit-review.php');
                                ?>
                            </div>
                        </div>
                    </td>
                    <td>
                        <div class="d-flex align-items-start">
                            <div class="flex-grow-1">
                                <?php
                                $point = $medication;
                                include resource_path('views/app/patient/segment-templates/_child_plan/last-plan.php');
                                ?>
                            </div>
                            <a class="px-1 view-review-log"
                               native target="_blank"
                               open-in-stag-popup
                               popup-style="stag-popup-md"
                               title="Plan log<?= !!@($medication->data->name) ? ' for ' . @($medication->data->name) : '' ?>"
                               href="/point/plan-log/<?= $medication->uid ?>?popupmode=1">
                                <i class="fa fa-history"></i>
                            </a>
                        </div>
                    </td>
                </tr>
            <?php endforeach; ?>
        </table>
    </div>

    <div class="d-flex align-items-center">
        <div visit-moe large class="mt-1 w-100 border p-2 bg-white rounded">
            <!--<a href="#" start show class="btn btn-sm btn btn-outline-primary">+ Add medication patient is ALREADY taking, prior to this visit</a>-->
            <form show url="/api/visitPoint/addTopLevelOnIntake" class="mcp-theme-1 w-100">
                <input type="hidden" name="segmentUid" value="<?= $segment->uid ?>">
                <input type="hidden" name="category" value="MEDICATION">
                <input type="hidden" name="data">

                <input type="hidden" data-name="medId">
                <input type="hidden" data-name="routedMedId">
                <input type="hidden" data-name="routedDosageFormMedId">
                <input type="hidden" data-name="gcnSeqno">

                <p class="mb-2"><b>Add Medication (on intake)</b></p>

                <div class="d-flex align-items-start">

                <div class="mb-2 w-25">
                    <label class="text-sm text-secondary mb-1 text-nowrap">Medication</label>
                    <input type="text"
                           data-name="name"
                           class="form-control form-control-sm"
                           stag-suggest
                           stag-suggest-ep="/fdb-med-suggest-v2/json">
                </div>
                <div class="mb-2 ml-2">
                    <label class="text-sm text-secondary mb-1 text-nowrap">Start Date</label>
                    <input type="date" class="form-control form-control-sm" data-name="start_date">
                </div>
                <div class="mb-2 ml-2">
                    <label class="text-sm text-secondary mb-1 text-nowrap">Prescribed By</label>
                    <input type="text" class="form-control form-control-sm" data-name="prescriber">
                </div>
                <div class="mb-2 ml-2 flex-grow-1">
                    <label class="text-sm text-secondary mb-1 text-nowrap">Description</label>
                    <textarea rows="1" data-name="description" class="form-control form-control-sm"></textarea>
                </div>
                </div>

                <div class="d-flex align-items-start">
                    <button submit class="btn btn-sm btn-primary mr-2">Submit</button>
                </div>
            </form>
        </div>
    </div>
</div>


<script>
    window.segmentInitializers.<?= $segment->segmentTemplate->internal_name ?> = function() {
        // any JS can come here
        // will be run on page-load as well as whenever this segment is refreshed

        let parentSegment = $('[data-segment-template-name="<?= $segment->segmentTemplate->internal_name ?>"] ');
        parentSegment.find('input[stag-suggest][data-name="name"]')
            .off('stag-suggest-selected')
            .on('stag-suggest-selected', (_e, _input, _data) => {

                // _input is the textbox
                // _data is {
                    // gcn_seqno: "78121"
                    // medid: "595384"
                    // routed_dosage_form_med_id: "437207"
                    // routed_med_id: "8814"
                    // text: "metoprolol succinate ER 100 mg capsule sprinkle, ext. release 24 hr"
                // }

                $(_input).closest('form').find('input[data-name="routedMedId"]').val(_data.routed_med_id);
                $(_input).closest('form').find('input[data-name="routedDosageFormMedId"]').val(_data.routed_dosage_form_med_id);
                $(_input).closest('form').find('input[data-name="gcnSeqno"]').val(_data.gcn_seqno);
                $(_input).closest('form').find('input[data-name="medId"]').val(_data.medid);

                return false;
            });

    };
</script>

