<?php

use App\Models\Point;
use \App\Models\Client;
use \App\Models\Note;
use \App\Models\Segment;

/** @var Client $patient */
/** @var Note $note */
/** @var Segment $segment */

$problems = Point::getIntakePointsOfCategory($patient, 'PROBLEM', $note);

?>
<div>

    <div class="d-flex mb-2">
        <table class="table table-sm table-bordered table-striped mb-0 bg-white">
            <thead>
            <tr class="">
                <th class="border-bottom-0 width-100px text-info">Relevant to<br>this visit</th>
                <th class="border-bottom-0">Problem</th>
                <th class="border-bottom-0">Most Recent Subjective</th>
                <th class="border-bottom-0">Most Recent Plan</th>
            </tr>
            </thead>
            <?php foreach($problems as $problem): ?>
                <?php $rel = $problem->relevanceToNote($note); ?>
            <tr>
                <td class="p-0">
                    <label class="d-flex align-items-center px-2 py-1 m-0 c-pointer">
                        <input type="checkbox" class="m-0 chk-relevance"
                               data-point-uid="{{$problem->uid}}"
                               data-rel-uid="{{$rel ? $rel->uid : ''}}"
                                {{$rel ? 'checked' : ''}}>
                    </label>
                </td>
                <td>
                    <div class="d-flex align-items-baseline">
                        <div class="<?= $problem->is_removed ? 'strike-through' : '' ?>">
                            <b><?= !!@($problem->data->name) ? @($problem->data->name) : '-' ?></b>
                            <?= !!@($problem->data->icd) ? '/&nbsp;' . @($problem->data->icd) : '' ?>
                            <?= !!@($problem->data->description) ? '/&nbsp;' . @($problem->data->description) : '' ?>
                        </div>

                        <!-- common actions -->
                        <div class="ml-auto d-inline-flex align-items-baseline pr-2">
                            <?php
                            $point = $problem;
                            $label = 'Problem';
                            include resource_path('views/app/patient/segment-templates/_common_actions/remove-undo.php');
                            ?>
                            @if($point->added_in_note_id === $note->id && $point->addition_reason_category == 'ON_INTAKE')
                            <div visit-moe class="ml-2">
                                <a href="#" start show class="">Swap</a>
                                <form url="/api/visitPoint/swapTopLevelEntryError" class="mcp-theme-1">
                                    <input type="hidden" name="uid" value="<?= $point->uid ?>">
                                    <input type="hidden" name="segmentUid" value="<?= $segment->uid ?>">
                                    <input type="hidden" name="category" value="PROBLEM">
                                    <input type="hidden" name="data">

                                    <input type="hidden" data-name="dxid">
                                    <input type="hidden" data-name="icd-type">

                                    <p class="mb-2"><b>Add Problem (on intake)</b></p>

                                    <div class="mb-2">
                                        <label class="text-sm text-secondary mb-1">Name</label>
                                        <input type="text" data-name="name" class="form-control form-control-sm"
                                               stag-suggest
                                               stag-suggest-ep="/fdb-dx-suggest/json">
                                    </div>

                                    <div class="mb-2">
                                        <label class="text-sm text-secondary mb-1">ICD</label>
                                        <select data-name="icd"
                                                class="form-control form-control-sm"
                                                disabled>
                                        </select>
                                    </div>

                                    <div class="mb-2">
                                        <label class="text-sm text-secondary mb-1">Description</label>
                                        <textarea type="text" data-name="description" class="form-control form-control-sm"></textarea>
                                    </div>

                                    <div>
                                        <button submit class="btn btn-sm btn-primary mr-2">Submit</button>
                                        <button cancel class="btn btn-sm btn-default border">Cancel</button>
                                    </div>
                                </form>
                            </div>
                            @endif
                        </div>
                    </div>
                </td>
                <td>
                    <div class="d-flex align-items-start">
                        <div class="flex-grow-1">
                            <?php
                            $point = $problem;
                            include resource_path('views/app/patient/segment-templates/_child_review/last-review.php');
                            ?>
                        </div>
                        <div class="d-inline-flex flex-nowrap">
                            <a class="px-1 view-review-log"
                               native target="_blank"
                               open-in-stag-popup
                               popup-style="stag-popup-md"
                               title="Subjective log<?= !!@($problem->data->name) ? ' for ' . @($problem->data->name) : '' ?>"
                               href="/point/review-log/<?= $problem->uid ?>?popupmode=1">
                                <i class="fa fa-history"></i>
                            </a>
                            <?php
                            include resource_path('views/app/patient/segment-templates/_child_review/edit-review.php');
                            ?>
                        </div>
                    </div>
                </td>
                <td>
                    <div class="d-flex align-items-start">
                        <div class="flex-grow-1">
                            <?php
                            $point = $problem;
                            include resource_path('views/app/patient/segment-templates/_child_plan/last-plan.php');
                            ?>
                        </div>
                        <a class="px-1 view-review-log"
                           native target="_blank"
                           open-in-stag-popup
                           popup-style="stag-popup-md"
                           title="Plan log<?= !!@($problem->data->name) ? ' for ' . @($problem->data->name) : '' ?>"
                           href="/point/plan-log/<?= $problem->uid ?>?popupmode=1">
                            <i class="fa fa-history"></i>
                        </a>
                    </div>
                </td>
            </tr>
            <?php endforeach; ?>
        </table>
    </div>

    <div class="d-flex align-items-center">
        <div visit-moe large class="mt-1 w-100 border p-2 bg-white rounded">
            <!--<a href="#" start show class="btn btn-sm btn btn-outline-primary">+ Add Problem patient is ALREADY having, prior
                to this visit</a>-->
            <form show url="/api/visitPoint/addTopLevelOnIntake" class="mcp-theme-1 w-100">
                <input type="hidden" name="segmentUid" value="<?= $segment->uid ?>">
                <input type="hidden" name="category" value="PROBLEM">
                <input type="hidden" name="data">

                <input type="hidden" data-name="dxid">
                <input type="hidden" data-name="icd-type">

                <p class="mb-2"><b>Add Problem (on intake)</b></p>

                <div class="d-flex align-items-start">

                <div class="mb-2 w-25">
                    <label class="text-sm text-secondary mb-1">Name</label>
                    <input type="text" data-name="name" class="form-control form-control-sm"
                           stag-suggest
                           stag-suggest-ep="/fdb-dx-suggest/json">
                </div>

                <div class="mb-2 w-25 ml-2">
                    <label class="text-sm text-secondary mb-1">ICD</label>
                    <select data-name="icd"
                            class="form-control form-control-sm"
                            disabled>
                    </select>
                </div>

                <div class="mb-2 ml-2 flex-grow-1">
                    <label class="text-sm text-secondary mb-1">Description</label>
                    <textarea rows="1" data-name="description" class="form-control form-control-sm"></textarea>
                </div>

                </div>

                <div>
                    <button submit class="btn btn-sm btn-primary mr-2">Submit</button>
                </div>
            </form>
        </div>
    </div>
</div>

<script>
    window.segmentInitializers.<?= $segment->segmentTemplate->internal_name ?> = function () {
        // any JS can come here
        // will be run on page-load as well as whenever this segment is refreshed

        let parentSegment = $('[data-segment-template-name="<?= $segment->segmentTemplate->internal_name ?>"] ');
        parentSegment.find('input[stag-suggest][data-name="name"]')
            .off('stag-suggest-selected')
            .on('stag-suggest-selected', (_e, _input, _data) => {

                // _input is the textbox
                // _data is {med_name_id: "50567", text: "Children's Tylenol"}

                $(_input).closest('form').find('input[data-name="dxid"]').val(_data.dxid);

                let icdSelect = $(_input).closest('form').find('[data-name="icd"]').empty().prop('disabled', true);

                $.get('/fdb-dx-icds-for-dxid?dxid=' + _data.dxid, _data => {
                    icdSelect
                        .empty()
                        .append('<option value="">-- select --</option>');
                    for (let i = 0; i < _data.length; i++) {
                        icdSelect.append('<option value="' + _data[i].search_icd_cd + '" data-icd-type="' + _data[i].icd_cd_type + '">' + _data[i].search_icd_cd + ' (' + (_data[i].icd_cd_type === '01' ? 'ICD-9' : 'ICD-10') + ') - ' + _data[i].icd_desc + '</option>')
                    }
                    icdSelect.prop('disabled', false);
                    if (_data.length === 1) {
                        icdSelect.val(_data[0].search_icd_cd).trigger('change');
                    }
                }, 'json');
            });

        // on route selection
        $(document).off('change', '[data-segment-template-name="<?= $segment->segmentTemplate->internal_name ?>"] [data-name="icd"]');
        $(document).on('change', '[data-segment-template-name="<?= $segment->segmentTemplate->internal_name ?>"] [data-name="icd"]', function () {
            $(this).closest('form').find('input[data-name="icd-type"]').val($(this).find('option:selected').attr('data-icd-type'));
        });

    };
</script>