<?php

use App\Models\Client;
use App\Models\Point;
use App\Models\Note;
/** @var Client $patient */
/** @var Note $note */
/** @var Segment $segment */

$fields = [
    [
        "Tobacco" => ["Current every day smoker", "Current some day smoker", "Former smoker", "Heavy tobacco smoker", "Light tobacco smoker", "Never smoker", "Smoker, current status unknown", "Unknown if ever smoked "],
    ],
    [
        "Alcohol" => ["Do not drink", "Drink daily", "Frequently drink", "Hx of Alcoholism", "Occasional drink"],
        "Drug Abuse" => ["IVDU", "Illicit drug use", "No illicit drug use"],
    ],
    [
        "Cardiovascular" => ["Eat healthy meals", "Regular exercise", "Take daily aspirin"],
        "Safety" => ["Household Smoke detector", "Keep Firearms in home", "Wear seatbelts"],
    ],
    [
        "Sexual Activity" => ["Exposure to STI", "Homosexual encounters", "Not sexually active", "Safe sex practices", "Sexually active"],
        "Birth Gender" => ["Male", "Female", "Undifferentiated"],
    ]
];

if(!@$note) {
    $note = $patient->coreNote;
}
if(!@$sessionKey) {
    $sessionKey = request()->cookie('sessionKey');
}

$point = Point::getOrCreateOnlyTopLevelPointOfCategory($note, 'SOCIAL_HISTORY', $sessionKey, true);

$contentData = $parsed = false;

$rel = !!$point->relevanceToNote($note);

if ($point->lastChildReview && $point->lastChildReview->data && ($rel || $point->lastChildReview->added_in_note_id === $note->id)) {
    $point->lastChildReview->data = json_decode($point->lastChildReview->data, true);
    $contentData = $parsed = $point->lastChildReview->data;

    $prevHead = ''; $items = [];
    for ($i = 0; $i < count($fields); $i++) {
        foreach($fields[$i] as $head => $values) {
            $items = [];
            for($k = 0; $k < count($values); $k++) {
                $fName = $head . '_' . sanitize_field_name($values[$k]);
                if(@$contentData['common'][$fName]) {
                    $items[] = $values[$k] . (@$contentData['common'][$fName . '__comments'] ? '<span class="text-sm ml-1 text-secondary">(' . $contentData['common'][$fName . '__comments'] . ')</span>' : '');
                }
            }
            if(count($items) && trim(implode('', $items)) !== '') {
            ?>
                <div>
                    <b><?= $head ?></b>
                    <i class="fa fa-arrow-right text-sm text-secondary"></i>
                    <?= implode(' • ', $items) ?>
                </div>
            <?php
            }
        }
    }

    // custom fields

    if(isset($contentData['customFields']) && count($contentData['customFields'])):
        ?> <div class=""> <?php
        for ($i = 0; $i < count($contentData['customFields']); $i++):
            $item = $contentData['customFields'][$i];
            if($item['value']): ?>
                <div>
                    Custom
                    <i class="fa fa-arrow-right text-sm text-secondary"></i>
                    <span class="font-weight-normal"><?= $item['label'] ?></span>
                    <?php if($item['comments']): ?>
                        <span class="text-sm ml-1 text-secondary">(<?= $item['comments'] ?>)</span>
                    <?php endif; ?>
                </div>
            <?php
            endif;
        endfor;
        ?> </div> <?php
    endif;

    if(isset($contentData['comments']) && !empty(trim($contentData['comments']))) { ?>
        <div class="mt-2 mb-1">
            <b>Comments: </b><?= $contentData['comments'] ?>
        </div>
    <?php }
}
else {
    echo '<span class="text-secondary">-</span>';
}
?>
