<?php
if(!@$sessionKey) {
    $sessionKey = request()->cookie('sessionKey');
}
$point = App\Models\Point::getOrCreateOnlyTopLevelPointOfCategory($note, 'VITALS', $sessionKey, true);
$vitalLabels = [
    "heightInInches" => "Ht. (in.)",
    "weightPounds" => "Wt. (lbs.)",
    "bmi" => "BMI (kg/m²)",
    "temperatureF" => "Temp. (F)",
    "systolicBP" => "SBP",
    "diastolicBP" => "DBP",
    "pulseRatePerMinute" => "Pulse",
    "respirationRatePerMinute" => "Resp.",
    "pulseOx" => "Pulse Ox.",
    "smokingStatus" => "Smoking Status",
];
$contentData = null;
if ($point->lastChildReview && $point->lastChildReview->note->id === $note->id && $point->lastChildReview->data) {
    $point->lastChildReview->data = json_decode($point->lastChildReview->data, true);
    $contentData = $point->lastChildReview->data;
}

if(!$contentData) {
    $contentData = [
        "date" => $note->effective_dateest,
        "heightInInches" => '',
        "weightPounds" => '',
        "bmi" => '',
        "temperatureF" => '',
        "systolicBP" => '',
        "diastolicBP" => '',
        "pulseRatePerMinute" => '',
        "respirationRatePerMinute" => '',
        "pulseOx" => '',
        "smokingStatus" => '',
    ];
}else {
    if(!isset($contentData['date'])) $contentData['date'] = $note->effective_dateest;
    foreach ($vitalLabels as $k => $v) {
        if (!isset($contentData[$k]) || is_array($contentData[$k])) {
            $contentData[$k] = '';
        }
    }
}
?>

{{--<div class="mb-2">Effective Date: <b>{{friendly_date($contentData['date'])}}</b></div>--}}
<div class="d-flex flex-wrap">
@foreach ($vitalLabels as $k => $v)
    @if($k !== 'diastolicBP')
        <div class="d-inline-flex vital-item align-items-center mr-3 mb-1">
            <span class="content-html text-nowrap">
                <?php $vital = @$contentData[$k]; ?>
                @if($k === 'systolicBP')
                    <span>BP:</span>
                    <b>{{ @$contentData['systolicBP'] ?: '-' }}/{{ @$contentData['diastolicBP'] ?: '-' }}</b>
                @elseif($k === 'diastolicBP')
                    <!--ignore-->
                @elseif($k === 'heightInInches')
                    <span>Ht:</span>
                    <b>{{ !empty($vital) ? toFeetAndInches($vital, "'", '"') : '-' }}</b>
                @elseif($k === 'weightPounds')
                    <span>Wt:</span>
                    <b>{{ !empty($vital) ? $vital : '-' }}</b>
                @elseif($k === 'bmi')
                    <span>BMI:</span>
                    <b>{{ !empty($vital) ? $vital : '-' }}</b>
                @elseif($k === 'temperatureF')
                    <span>Temp:</span>
                    <b>{{ !empty($vital) ? $vital : '-' }}</b>
                @elseif($k === 'smokingStatus')
                    <span>Smoking:</span>
                    <b>{{ !empty($vital) ? $vital : '-' }}</b>
                @else
                    <span>{{$v}}:</span>
                    <b>{{ !empty($vital) ? $vital : '-' }}</b>
                @endif
                @if($k === 'bmi' && !empty($vital))
                    <?php $bmi = floatval($vital); ?>
                    <span class="ml-1 py-1 m-0">
                         @if($bmi < 18.5)
                            <span class="text-warning-mellow">(Underweight)</span>
                         @endif
                        @if($bmi >= 18.5 && $bmi < 25)
                             <!--<span class="text-sm text-success">(Healthy Weight)</span>-->
                        @endif
                        @if($bmi >= 25 && $bmi < 30)
                            <span class="text-warning-mellow">(Overweight)</span>
                        @endif
                        @if($bmi >= 30)
                            <span class="text-warning-mellow">(Obese)</span>
                        @endif
                    </span>
                @endif
            </span>
        </div>
        @if(in_array($k, ['bmi', 'temperatureF', 'respirationRatePerMinute']))<br>@endif
    @endif
@endforeach
</div>
